==> soxo-bootstrap-core-2.2.11.tgz: package/core/modules/Informations/change-info/change-info.js <==
/**
 * @description
 * @author Sneha
 *
 * The component used to change information
 *
 *
 */

import React, { useState, useContext, useEffect } from 'react';

import { Steps, Button, message } from 'antd';

import './change-info.scss';

import { GlobalContext, FormCreator } from '../../../lib';

import { CoreScripts, Preferences } from '../../../models';

import PropTypes from 'prop-types';

/**
 *
 * @param root0
 * @param root0.reportId
 * @param root0.preferenceId
 * @returns {*}
 */
function ChangeInfo({ reportId, preferenceId }) {
  //Representing steps

  // Track the curren    //Representing steps
  const { Step } = Steps;

  // Track the current step in the process
  const [currentStep, setCurrentStep] = useState(0);

  // Store  details returned by coreScript
  const [paramterData, setParameterData] = useState([]);

  // Store patient details fetched from the backend
  const [displayColumns, setdisplayColumns] = useState([]);

  // Loading state
  const [loading, setLoading] = useState(true);

  // Store patients list
  const [information, setInformation] = useState([]);

  // Store selected patients
  const [selectedInformation, setSelectedInformation] = useState([]);

  // Retrieve global context data
  const { CustomModels = {} } = useContext(GlobalContext);

  /** Next step */
  const next = () => {
    setCurrentStep(currentStep + 1);
  };

  /** Previous step*/
  function prev() {
    //If currentstage is 2, beacuse we don't need setSelectedPatients there
    if (currentStep === 2) {
      // Clear selected patients when going back from step 2
      setSelectedInformation([]);
    }

    setCurrentStep(currentStep - 1);
  }

  /**
   * Fetch patient details when the component mountsGo back to the previous step
   */
  useEffect(() => {
    /**Get information */
    getInformation();
  }, []);

  /**
   * Function to fetch patient details from the backend
   */
  const getInformation = async () => {
    //CoreScript Id
    let id = reportId.selectId;

    //Getting records from coreScripts corresponding to the id
    CoreScripts.getRecord({ id }).then(({ result }) => {
      // Prepare input parameters for the form
      prepareInputParameters(result.input_parameters);

      // Set details from the fetched data
      setdisplayColumns(JSON.parse(result.display_columns));
    });
  };

  /**
   * Prepare input parameters for the form
   * @param {object} inputParameters
   */
  const prepareInputParameters = async (inputParameters) => {
    setLoading(true);

    // Parse input parameters
    let parameters = JSON.parse(inputParameters);

    // Map and set form content based on parameters and URL params
    parameters = await parameters.map((record) => {
      if (['reference-select', 'reference-search'].indexOf(record.type) !== -1) {
        /**Get custom model based on the model name */
        let model = CustomModels[record.modelName];

        return { ...record, model };
      } else {
        return { ...record };
      }
    });

    setLoading(false);

    // Set details with prepared parameters
    setParameterData([...parameters]);
  };

  /**
   * Handle form submission
   * @param {Object} values
   */
  const handleFormSubmit = async (values) => {
    //ID
    let id;

    //Formbody
    let formBody;

    //If there is selectedPatients we need to update the patient details
    if (currentStep === 2) {
      //CoreScript Id for updation
      id = reportId.editId;

      //Defining formbody
      formBody = {
        body: {
          // Values for replacing
          values,

          selectedData: selectedInformation,
        },
      };

      //Getting coreScript data for updation
      await CoreScripts.getUserDetailsLisitng(id, formBody).then((result) => {
        let resultDetails = result;

        //If there is data and message is suceess
        if (resultDetails && resultDetails.message === 'sucess') {
          // Update information list
          setInformation(resultDetails);

          message.success('Profile updated and submitted successfully!');

          // Clear selectedData and reset to the first step
          setSelectedInformation([]);

          //Setting step back to init
          setCurrentStep(0);
        }

        setLoading(false);
      });

      {
        /**Else */
      }
    } else {
      /**If there is selectedInformation we need to update the patient details */
      formBody = { body: values };

      /**Id for getting coreScrpt data */
      id = reportId.selectId;

      //Getting coreScript data for getting
      await CoreScripts.getReportingLisitng(id, formBody).then((result) => {
        let resultDetails = result[0] || (result?.result && result?.result[0]);

        if (resultDetails) {
          // Update information list
          setInformation(resultDetails);

          // Proceed to the next step
          next();
        }

        setLoading(false);
      });
    }

    setLoading(true);
  };

  /**
   * Handle patient selection
   * @param {Array} selected
   */

  /**
   *
   * @param selected
   */
  const handlePatientSelection = (selected) => {
    // Update selected patients
    setSelectedInformation(selected);
  };

  /**
   * Render through each stages
   *
   * @param {number} step
   * @returns {JSX.Element} The rendered component corresponding to the current step.
   */
  const renderSwitch = (step) => {
    switch (step) {
      case 0:
        return (
          <InitialContent
            next={next}
            prev={prev}
            fields={paramterData}
            selectedData={null}
            currentStep={currentStep}
            preferenceId={preferenceId}
            onSubmit={handleFormSubmit}
          />
        );

      case 1:
        return <GuestDetails next={next} prev={prev} displayColumns={displayColumns} information={information} onSelect={handlePatientSelection} />;

      case 2:
        return (
          <>
            <div className="change-info-container">
              <div className="change-infoheader">Current information</div>

              {/*Looping through selected data  */}
              {selectedInformation.map((patient, index) => (
                <div key={index} className="info-items">
                  {/** Matching the selected data with the display columns */}
                  {displayColumns.map((detail, idx) => {
                    //Display columns fieild
                    const fieldName = detail.field;

                    //MAatchined values
                    const fieldValue = patient[fieldName];

                    return (
                      <div key={idx} className="info-field">
                        <span>{detail.title}:</span>

                        <span className="value">{fieldValue !== undefined ? fieldValue : 'N/A'}</span>

                        {/** Selected data */}
                        {patient.selected && <span className="selected">(selected)</span>}
                      </div>
                    );
                  })}
                </div>
              ))}
            </div>
            <InitialContent
              next={next}
              prev={prev}
              fields={null}
              currentStep={currentStep}
              selectedData={selectedInformation}
              onSubmit={handleFormSubmit}
              preferenceId={preferenceId}
            />

          </>
        );

      default:
        return <InitialContent next={next} fields={paramterData} loading={loading} currentStep={currentStep} onSubmit={handleFormSubmit} />;
    }
  };

  return (
    <div className="change-profile-head">
      <div className="change-profile card">
        <Steps size="small" current={currentStep}>
          <Step title="Enter" />

          <Step title="Edit" />

          <Step title="Select" />
        </Steps>
      </div>

      <FormContent renderSwitch={renderSwitch} currentStep={currentStep} />
    </div>
  );
}

// Define PropTypes for the component
ChangeInfo.propTypes = {
  reportId: PropTypes.object,
  preferenceId: PropTypes.number,
};

export default ChangeInfo;

/**
 * Responsible for rendering the content of the form based on the current step
 * @param {*} renderSwitch
 * @param {number} currentStep
 */

/**
 *
 * @param root0
 * @param root0.renderSwitch
 * @param root0.currentStep
 *  @returns {JSX.Element}  JSX content
 */
function FormContent({ renderSwitch, currentStep }) {
  return (
    /* Rebder formConetent */
    <div className="formcreator card">{renderSwitch(currentStep)}</div>
  );
}

FormContent.propTypes = {
  renderSwitch: PropTypes.func.isRequired,
  currentStep: PropTypes.number,
};

/**
 * @param root0
 * @param root0.next
 * @param root0.prev
 * @param root0.fields
 * @param root0.onSubmit
 * @param root0.selectedData
 * @param root0.currentStep
 * @param root0.preferenceId
 * @returns {JSX.Element}  JSX content
 */
function InitialContent({ next, prev, fields, onSubmit, selectedData, currentStep, preferenceId }) {
  /** @type {string} */

  let formLayout = 'inline';

  // Store preferences
  const [preference, setPreference] = useState({});

  /**
   * Fetch patient details if selected data exists.
   * @param {*}
   * @returns {*}
   */
  useEffect(() => {
    /**Cheaking if there is selectedData */
    if (selectedData && selectedData.length > 0) {
      getPatientDetail();
    }
  }, []);

  /**
   * Get details
   */
  const getPatientDetail = async () => {
    /**  Defining preference id*/
    let id = preferenceId;

    Preferences.getRecord({ id }).then(({ result }) => {
      let data = JSON.parse(result.scope_value);

      setPreference(data.fields);

      return result;
    });
  };

  /**
   *  Render the form based on the details or preferences fetched
   *
   * @returns
   */
  const renderForm = () => {
    if ((fields && fields.length > 0) || (preference && preference.length > 0)) {
      return (
        <FormCreator
          layout={formLayout}
          initialValues={{ layout: formLayout }}
          styles={{ paddingRight: '15px', alignItems: 'center' }}
          fields={fields ? fields : preference}
          modelIndex="requestId"
          model={{ fields: fields ? fields : preference }}
          onSubmit={onSubmit}
        />
      );
    }
  };

  return (
    <div>
      {/* We use this page for step 0 and 1 but we need this part only for 0 */}
      {currentStep === 0 && (
        <div>
          <h4>Search your Email</h4>

          <p>Update your email for seamless communication</p>
        </div>
      )}

      {renderForm()}

      <div>
        {/* We use this page for step 0 and 2 but we need bacck button all stages except 0 */}
        {currentStep !== 0 && (
          <Button type="default" onClick={prev} style={{ marginTop: '20px', marginRight: '10px' }}>
            Back
          </Button>
        )}

        {/* We use this page for step 0 and 2 but we need this part only for 2 */}
        {currentStep === 1 && (
          <Button type="primary" onClick={next} style={{ marginTop: '20px', marginLeft: '10px' }}>
            Next
          </Button>
        )}
      </div>
    </div>
  );
}

InitialContent.propTypes = {
  next: PropTypes.func.isRequired,
  prev: PropTypes.func.isRequired,
  fields: PropTypes.array,
  onSubmit: PropTypes.func.isRequired,
  selectedData: PropTypes.array,
  currentStep: PropTypes.number.isRequired,
  preferenceId: PropTypes.number.isRequired,
};

/**
 * Handles the step where users select patients
 * @param root0
 * @param  root0.next
 * @param root0.prev
 * @param root0.information
 * @param root0.onSelect
 * @param root0.displayColumns
 *  @returns {JSX.Element} The rendered component corresponding to the data
 * Render renderAdditionalInfo
 */
function GuestDetails({ next, prev, information, onSelect, displayColumns }) {
  // Track selected patients
  const [selectedInformation, setSelectedInformation] = useState([]);

  // Handle checkbox change to select/deselect patients
  /**
   *
   * @param patient
   * @param isChecked
   */
  const handleCheckboxChange = (patient, isChecked) => {
    const updatedInformation = isChecked ? [...selectedInformation, patient] : selectedInformation.filter((p) => p !== patient);

    /* Setting selected datas */
    setSelectedInformation(updatedInformation);

    onSelect(updatedInformation);
  };

  /**
   * Render renderAdditionalInfo
   * @param {Array} data
   * @returns {object} displayColumns
   */
  const renderAdditionalInfo = (data) => {
    /* Matching selected data with the display columns */
    return displayColumns.map((detail, index) => {
      const fieldName = detail.field;

      return (
        <div key={index} className="selected-info-item">
          <span className="selected-info-field">{detail.title}:</span>

          <span className="selected-value">{data[fieldName] || 'N/A'}</span>
        </div>
      );
    });
  };

  return (
    <div>
      {/* If the coreScript data contains data */}
      {information && information.length > 0 ? (
        information.map((data, index) => (
          <div className="change-info card" key={index} style={{ marginBottom: '10px' }}>
            <div className="change-info-details">
              <div className="change-info-patient-info">
                <input type="checkbox" className="patient-checkbox" 
               onChange={(e) => handleCheckboxChange(data, e.target.checked)}
               disabled={selectedInformation.length > 0 && !selectedInformation.includes(data)}/>
              </div>

              <div className="additional-info">{renderAdditionalInfo(data)}</div>
            </div>
          </div>
        ))
      ) : (
        <p>No patient data available</p>
      )}

      <Button type="default" onClick={prev}>
        Back
      </Button>

      <Button
        type="primary"
        onClick={next}
        style={{ marginTop: '20px', marginLeft: '10px' }}
        // Disable button if no patients are selected
        disabled={selectedInformation.length === 0}
      >
        Edit Details
      </Button>
    </div>
  );
}

GuestDetails.propTypes = {
  next: PropTypes.func.isRequired,
  prev: PropTypes.func.isRequired,
  onSelect: PropTypes.array,
  displayColumns: PropTypes.object,
  information: PropTypes.array,
};

==> soxo-bootstrap-core-2.2.13.tgz: package/core/modules/Informations/change-info/change-info.js <==
/**
 * @description
 * @author Sneha
 *
 * The component used to change information
 *
 *
 */

import React, { useState, useContext, useEffect } from 'react';

import { Steps, Button, message } from 'antd';

import './change-info.scss';

import { GlobalContext, FormCreator } from '../../../lib';

import { CoreScripts, Preferences } from '../../../models';

import PropTypes from 'prop-types';

/**
 *
 * @param root0
 * @param root0.reportId
 * @param root0.preferenceId
 * @returns {*}
 */
function ChangeInfo({ reportId, preferenceId }) {
  //Representing steps

  // Track the curren    //Representing steps
  const { Step } = Steps;

  // Track the current step in the process
  const [currentStep, setCurrentStep] = useState(0);

  // Store  details returned by coreScript
  const [paramterData, setParameterData] = useState([]);

  // Store patient details fetched from the backend
  const [displayColumns, setdisplayColumns] = useState([]);

  // Loading state
  const [loading, setLoading] = useState(true);

  // Store patients list
  const [information, setInformation] = useState([]);

  // Store selected patients
  const [selectedInformation, setSelectedInformation] = useState([]);

  // Retrieve global context data
  const { CustomModels = {} } = useContext(GlobalContext);

  /** Next step */
  const next = () => {
    setCurrentStep(currentStep + 1);
  };

  /** Previous step*/
  function prev() {
    //If currentstage is 2, beacuse we don't need setSelectedPatients there
    if (currentStep === 2) {
      // Clear selected patients when going back from step 2
      setSelectedInformation([]);
    }

    setCurrentStep(currentStep - 1);
  }

  /**
   * Fetch patient details when the component mountsGo back to the previous step
   */
  useEffect(() => {
    /**Get information */
    getInformation();
  }, []);

  /**
   * Function to fetch patient details from the backend
   */
  const getInformation = async () => {
    //CoreScript Id
    let id = reportId.selectId;

    //Getting records from coreScripts corresponding to the id
    CoreScripts.getRecord({ id }).then(({ result }) => {
      // Prepare input parameters for the form
      prepareInputParameters(result.input_parameters);

      // Set details from the fetched data
      setdisplayColumns(JSON.parse(result.display_columns));
    });
  };

  /**
   * Prepare input parameters for the form
   * @param {object} inputParameters
   */
  const prepareInputParameters = async (inputParameters) => {
    setLoading(true);

    // Parse input parameters
    let parameters = JSON.parse(inputParameters);

    // Map and set form content based on parameters and URL params
    parameters = await parameters.map((record) => {
      if (['reference-select', 'reference-search'].indexOf(record.type) !== -1) {
        /**Get custom model based on the model name */
        let model = CustomModels[record.modelName];

        return { ...record, model };
      } else {
        return { ...record };
      }
    });

    setLoading(false);

    // Set details with prepared parameters
    setParameterData([...parameters]);
  };

  /**
   * Handle form submission
   * @param {Object} values
   */
  const handleFormSubmit = async (values) => {
    //ID
    let id;

    //Formbody
    let formBody;

    //If there is selectedPatients we need to update the patient details
    if (currentStep === 2) {
      //CoreScript Id for updation
      id = reportId.editId;

      //Defining formbody
      formBody = {
        body: {
          // Values for replacing
          values,

          selectedData: selectedInformation,
        },
      };

      //Getting coreScript data for updation
      await CoreScripts.getUserDetailsLisitng(id, formBody).then((result) => {
        let resultDetails = result;

        //If there is data and message is suceess
        if (resultDetails && resultDetails.message === 'sucess') {
          // Update information list
          setInformation(resultDetails);

          message.success('Profile updated and submitted successfully!');

          // Clear selectedData and reset to the first step
          setSelectedInformation([]);

          //Setting step back to init
          setCurrentStep(0);
        }

        setLoading(false);
      });

      {
        /**Else */
      }
    } else {
      /**If there is selectedInformation we need to update the patient details */
      formBody = { body: values };

      /**Id for getting coreScrpt data */
      id = reportId.selectId;

      //Getting coreScript data for getting
      await CoreScripts.getReportingLisitng(id, formBody).then((result) => {
        let resultDetails = result[0] || (result?.result && result?.result[0]);

        if (resultDetails) {
          // Update information list
          setInformation(resultDetails);

          // Proceed to the next step
          next();
        }

        setLoading(false);
      });
    }

    setLoading(true);
  };

  /**
   * Handle patient selection
   * @param {Array} selected
   */

  /**
   *
   * @param selected
   */
  const handlePatientSelection = (selected) => {
    // Update selected patients
    setSelectedInformation(selected);
  };

  /**
   * Render through each stages
   *
   * @param {number} step
   * @returns {JSX.Element} The rendered component corresponding to the current step.
   */
  const renderSwitch = (step) => {
    switch (step) {
      case 0:
        return (
          <InitialContent
            next={next}
            prev={prev}
            fields={paramterData}
            selectedData={null}
            currentStep={currentStep}
            preferenceId={preferenceId}
            onSubmit={handleFormSubmit}
          />
        );

      case 1:
        return <GuestDetails next={next} prev={prev} displayColumns={displayColumns} information={information} onSelect={handlePatientSelection} />;

      case 2:
        return (
          <>
            <div className="change-info-container">
              <div className="change-infoheader">Current information</div>

              {/*Looping through selected data  */}
              {selectedInformation.map((patient, index) => (
                <div key={index} className="info-items">
                  {/** Matching the selected data with the display columns */}
                  {displayColumns.map((detail, idx) => {
                    //Display columns fieild
                    const fieldName = detail.field;

                    //MAatchined values
                    const fieldValue = patient[fieldName];

                    return (
                      <div key={idx} className="info-field">
                        <span>{detail.title}:</span>

                        <span className="value">{fieldValue !== undefined ? fieldValue : 'N/A'}</span>

                        {/** Selected data */}
                        {patient.selected && <span className="selected">(selected)</span>}
                      </div>
                    );
                  })}
                </div>
              ))}
            </div>
            <InitialContent
              next={next}
              prev={prev}
              fields={null}
              currentStep={currentStep}
              selectedData={selectedInformation}
              onSubmit={handleFormSubmit}
              preferenceId={preferenceId}
            />

          </>
        );

      default:
        return <InitialContent next={next} fields={paramterData} loading={loading} currentStep={currentStep} onSubmit={handleFormSubmit} />;
    }
  };

  return (
    <div className="change-profile-head">
      <div className="change-profile card">
        <Steps size="small" current={currentStep}>
          <Step title="Enter" />

          <Step title="Edit" />

          <Step title="Select" />
        </Steps>
      </div>

      <FormContent renderSwitch={renderSwitch} currentStep={currentStep} />
    </div>
  );
}

// Define PropTypes for the component
ChangeInfo.propTypes = {
  reportId: PropTypes.object,
  preferenceId: PropTypes.number,
};

export default ChangeInfo;

/**
 * Responsible for rendering the content of the form based on the current step
 * @param {*} renderSwitch
 * @param {number} currentStep
 */

/**
 *
 * @param root0
 * @param root0.renderSwitch
 * @param root0.currentStep
 *  @returns {JSX.Element}  JSX content
 */
function FormContent({ renderSwitch, currentStep }) {
  return (
    /* Rebder formConetent */
    <div className="formcreator card">{renderSwitch(currentStep)}</div>
  );
}

FormContent.propTypes = {
  renderSwitch: PropTypes.func.isRequired,
  currentStep: PropTypes.number,
};

/**
 * @param root0
 * @param root0.next
 * @param root0.prev
 * @param root0.fields
 * @param root0.onSubmit
 * @param root0.selectedData
 * @param root0.currentStep
 * @param root0.preferenceId
 * @returns {JSX.Element}  JSX content
 */
function InitialContent({ next, prev, fields, onSubmit, selectedData, currentStep, preferenceId }) {
  /** @type {string} */

  let formLayout = 'inline';

  // Store preferences
  const [preference, setPreference] = useState({});

  /**
   * Fetch patient details if selected data exists.
   * @param {*}
   * @returns {*}
   */
  useEffect(() => {
    /**Cheaking if there is selectedData */
    if (selectedData && selectedData.length > 0) {
      getPatientDetail();
    }
  }, []);

  /**
   * Get details
   */
  const getPatientDetail = async () => {
    /**  Defining preference id*/
    let id = preferenceId;

    Preferences.getRecord({ id }).then(({ result }) => {
      let data = JSON.parse(result.scope_value);

      setPreference(data.fields);

      return result;
    });
  };

  /**
   *  Render the form based on the details or preferences fetched
   *
   * @returns
   */
  const renderForm = () => {
    if ((fields && fields.length > 0) || (preference && preference.length > 0)) {
      return (
        <FormCreator
          layout={formLayout}
          initialValues={{ layout: formLayout }}
          styles={{ paddingRight: '15px', alignItems: 'center' }}
          fields={fields ? fields : preference}
          modelIndex="requestId"
          model={{ fields: fields ? fields : preference }}
          onSubmit={onSubmit}
        />
      );
    }
  };

  return (
    <div>
      {/* We use this page for step 0 and 1 but we need this part only for 0 */}
      {currentStep === 0 && (
        <div>
          <h4>Search your Email</h4>

          <p>Update your email for seamless communication</p>
        </div>
      )}

      {renderForm()}

      <div>
        {/* We use this page for step 0 and 2 but we need bacck button all stages except 0 */}
        {currentStep !== 0 && (
          <Button type="default" onClick={prev} style={{ marginTop: '20px', marginRight: '10px' }}>
            Back
          </Button>
        )}

        {/* We use this page for step 0 and 2 but we need this part only for 2 */}
        {currentStep === 1 && (
          <Button type="primary" onClick={next} style={{ marginTop: '20px', marginLeft: '10px' }}>
            Next
          </Button>
        )}
      </div>
    </div>
  );
}

InitialContent.propTypes = {
  next: PropTypes.func.isRequired,
  prev: PropTypes.func.isRequired,
  fields: PropTypes.array,
  onSubmit: PropTypes.func.isRequired,
  selectedData: PropTypes.array,
  currentStep: PropTypes.number.isRequired,
  preferenceId: PropTypes.number.isRequired,
};

/**
 * Handles the step where users select patients
 * @param root0
 * @param  root0.next
 * @param root0.prev
 * @param root0.information
 * @param root0.onSelect
 * @param root0.displayColumns
 *  @returns {JSX.Element} The rendered component corresponding to the data
 * Render renderAdditionalInfo
 */
function GuestDetails({ next, prev, information, onSelect, displayColumns }) {
  // Track selected patients
  const [selectedInformation, setSelectedInformation] = useState([]);

  // Track selected checkbox
  const [selectedCheckbox, setSelectedCheckbox] = useState();

  // Handle checkbox change to select/deselect patients
  /**
   *
   * @param patient
   * @param isChecked
   */
  const handleCheckboxChange = (patient, isChecked, index) => {
    const updatedInformation = isChecked ? [...selectedInformation, patient] : selectedInformation.filter((p) => p !== patient);

    /**If cheaked */
    if (isChecked) {
      /** Set selected checkbox by index */
      setSelectedCheckbox(index);
    } else {
      /**Deselect the checkbox if unchecked */
      setSelectedCheckbox(null);
    }

    /* Setting selected datas */
    setSelectedInformation(updatedInformation);

    onSelect(updatedInformation);
  };

  /**
   * Render renderAdditionalInfo
   * @param {Array} data
   * @returns {object} displayColumns
   */
  const renderAdditionalInfo = (data) => {
    /* Matching selected data with the display columns */
    return displayColumns.map((detail, index) => {
      const fieldName = detail.field;

      return (
        <div key={index} className="selected-info-item">
          <span className="selected-info-field">{detail.title}:</span>

          <span className="selected-value">{data[fieldName] || 'N/A'}</span>
        </div>
      );
    });
  };

  return (
    <div>
      {/* If the coreScript data contains data */}
      {information && information.length > 0 ? (
        information.map((data, index) => (
          <div className="change-info card" key={index} style={{ marginBottom: '10px' }}>
            <div className="change-info-details">
              <div className="change-info-patient-info">
                <input type="checkbox" className="patient-checkbox"
                  checked={selectedCheckbox === index} // Only selected checkbox will be checked
                  onChange={(e) => handleCheckboxChange(data, e.target.checked, index)} // Pass index to handler
                />
              </div>

              <div className="additional-info">{renderAdditionalInfo(data)}</div>
            </div>
          </div>
        ))
      ) : (
        <p>No patient data available</p>
      )}

      <Button type="default" onClick={prev}>
        Back
      </Button>

      <Button
        type="primary"
        onClick={next}
        style={{ marginTop: '20px', marginLeft: '10px' }}
        // Disable button if no patients are selected
        disabled={selectedInformation.length === 0}
      >
        Edit Details
      </Button>
    </div>
  );
}

GuestDetails.propTypes = {
  next: PropTypes.func.isRequired,
  prev: PropTypes.func.isRequired,
  onSelect: PropTypes.array,
  displayColumns: PropTypes.object,
  information: PropTypes.array,
};
